@@ -1,8 +1,6 @@
-import datetime
-
+from flask_monitoringdashboard.core.cache import update_duration_cache
 from flask_monitoringdashboard.core.profiler.baseProfiler import BaseProfiler
 from flask_monitoringdashboard.database import session_scope
-from flask_monitoringdashboard.database.endpoint import update_last_accessed
 from flask_monitoringdashboard.database.request import add_request
 
 
@@ -12,14 +10,22 @@ class PerformanceProfiler(BaseProfiler):
     Used when monitoring-level == 1
     """
 
-    def __init__(self, endpoint, ip, duration):
+    def __init__(self, endpoint, ip, duration, group_by, status_code=200):
         super(PerformanceProfiler, self).__init__(endpoint)
         self._ip = ip
         self._duration = duration * 1000  # Conversion from sec to ms
         self._endpoint = endpoint
+        self._group_by = group_by
+        self._status_code = status_code
 
     def run(self):
+        update_duration_cache(endpoint_name=self._endpoint.name, duration=self._duration)
         with session_scope() as db_session:
-            update_last_accessed(db_session, endpoint_name=self._endpoint.name)
-            print("mao")
-            add_request(db_session, duration=self._duration, endpoint_id=self._endpoint.id, ip=self._ip)
+            add_request(
+                db_session,
+                duration=self._duration,
+                endpoint_id=self._endpoint.id,
+                ip=self._ip,
+                group_by=self._group_by,
+                status_code=self._status_code,
+            )
