@@ -2,7 +2,11 @@ import datetime
 
 
 def to_local_datetime(dt):
-    """ Convert datetime (UTC) to local datetime based on the configuration """
+    """
+    Convert datetime (UTC) to local datetime based on the configuration.
+    :param dt: UTC datetime object
+    :return local datetime
+    """
     from flask_monitoringdashboard import config
 
     if dt:
@@ -11,7 +15,11 @@ def to_local_datetime(dt):
 
 
 def to_utc_datetime(dt):
-    """ Convert datetime (local) to UTC datetime based on the configuration """
+    """
+    Convert datetime (local) to UTC datetime based on the configuration.
+    :param dt: local datetime object
+    :return UTC datetime
+    """
     from flask_monitoringdashboard import config
 
     if dt:
