@@ -1,4 +1,4 @@
-from sqlalchemy import func, distinct, desc
+from sqlalchemy import func, desc
 
 from flask_monitoringdashboard.database import Request
 
@@ -9,26 +9,33 @@ def get_versions(db_session, endpoint_id=None, limit=None):
     :param db_session: session for the database
     :param endpoint_id: only get the version that are used in this endpoint
     :param limit: only return the most recent versions
-    :return: a list with the versions (as a string)
+    :return: a list of tuples with the versions (as a string) and dates, from oldest to newest
     """
-    query = db_session.query(distinct(Request.version_requested))
+    query = db_session.query(Request.version_requested, func.min(Request.time_requested))
     if endpoint_id:
         query = query.filter(Request.endpoint_id == endpoint_id)
-    query = query.order_by(desc(Request.time_requested))
+    query = query.group_by(Request.version_requested)
     if limit:
         query = query.limit(limit)
-    return list(reversed([r[0] for r in query.all()]))
+    return query.all()
 
 
-def get_first_requests(db_session, limit=None):
+def get_first_requests(db_session, endpoint_id, limit=None):
     """
     Returns a list with all versions and when they're first used
     :param db_session: session for the database
     :param limit: only return the most recent versions
-    :return:
+    :param endpoint_id: id of the endpoint
+    :return list of tuples with versions
     """
-    query = db_session.query(Request.version_requested, func.min(Request.time_requested).label('first_used')). \
-        group_by(Request.version_requested).order_by(desc('first_used'))
+    query = (
+        db_session.query(
+            Request.version_requested, func.min(Request.time_requested).label('first_used')
+        )
+        .filter(Request.endpoint_id == endpoint_id)
+        .group_by(Request.version_requested)
+        .order_by(desc('first_used'))
+    )
     if limit:
         query = query.limit(limit)
     return query.all()
