@@ -1,11 +1,15 @@
 import unittest
 
-from flask_monitoringdashboard.test.utils import set_test_environment, clear_db, add_fake_data, get_test_app, \
-    test_admin_secure
+from flask_monitoringdashboard.test.utils import (
+    set_test_environment,
+    clear_db,
+    add_fake_data,
+    get_test_app,
+    test_admin_secure,
+)
 
 
 class TestMeasurement(unittest.TestCase):
-
     def setUp(self):
         set_test_environment()
         clear_db()
